@@ -4,7 +4,7 @@ import numpy as np
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 import base.voie_base
 
-class SignalSysam():
+class Sysam():
     def __init__(self, nom):
         print("Sysam: ", end = "SignalSysam(")
         print("nom: ", nom, end = ")\n")        
