@@ -1,10 +1,14 @@
-Pa = 10 # Femax = 1e7
+Pa = 7 # Tanalog = 10**-Pa
 #Ta = 10**(-Pa)
 
-liste_tmin_tmax = [0., 1e-2]
-Te = 1e-6
+Nmax = 1e6 # nombre d'échantillons max dans un signal
 
-F = 100
+liste_xmin_xmax = [0., 1e-4]
+Xe = 10**-Pa
+
+
+
+F = 1e5
 Vpp = 2
 type_signal = "cosinus"
 
