@@ -11,7 +11,7 @@ from filtres.filtre_base import FiltreBase
 from signaux.signalll import Signal
 
 class FigureDynamique():
-    def dispay(self):
+    def display(self):
         try:
             __IPYTHON__
             display.display(self.figure)
