@@ -30,52 +30,52 @@ class Sysam1Base():
             utb.print_liste(self.liste_signaux)
 
         self.liste_entrees_simples = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_entree_simple(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_entree_simple(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_entrees_diffs = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_entree_diff(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_entree_diff(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_entrees = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_entree(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_entree(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_sorties = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_sortie(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_sortie(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_sortie1 = utb.lister_test(self.liste_sorties, 
-            lambda s: s.lire_voie_base().nom == "SA1",
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().nom == "SA1",
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_sortie2 = utb.lister_test(self.liste_sorties, 
-            lambda s: s.lire_voie_base().nom == "SA2",
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().nom == "SA2",
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_triggers = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_trigger_base().tester(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_trigger_base().tester(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_entrees_triggers = utb.lister_test(self.liste_entrees, 
-            lambda s: s.lire_trigger_base().tester(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_trigger_base().tester(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_sorties_triggers = utb.lister_test(self.liste_sorties, 
-            lambda s: s.lire_trigger_base().tester(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_trigger_base().tester(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         self.liste_paires_signaux_multiplex = utb.lister_paires_test(self.liste_signaux, 
-            lambda s1, s2: s1.lire_voie_base().tester_necessite_multiplexage(s2.lire_voie_base()),
-            lambda p: p[0].lire_voie_base().calculer_numero(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s1, s2: s1._Signal6Sysam__lire_voie_base().tester_necessite_multiplexage(s2._Signal6Sysam__lire_voie_base()),
+            lambda p: p[0]._Signal6Sysam__lire_voie_base().calculer_numero(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         
     def __enter__(self):
         return self
 
     def __exit__(self, *args, **kwargs):
-        # self.lire_voie_base().close()
+        # self._Signal6Sysam__lire_voie_base().close()
         pass
 
     def __del__(self):
